import Attr from '../../attribute/Attr';
import CSSStyleSheet from '../../css/CSSStyleSheet';
import HTMLElement from '../html-element/HTMLElement';
import IHTMLLinkElement from './IHTMLLinkElement';
import Event from '../../event/Event';
import ErrorEvent from '../../event/events/ErrorEvent';
/**
 * HTML Link Element.
 *
 * Reference:
 * https://developer.mozilla.org/en-US/docs/Web/API/HTMLLinkElement
 */
export default class HTMLLinkElement extends HTMLElement implements IHTMLLinkElement {
    onerror: (event: ErrorEvent) => void;
    onload: (event: Event) => void;
    readonly sheet: CSSStyleSheet;
    _evaluateCSS: boolean;
    /**
     * "true" if connected to DOM.
     *
     * @return "true" if connected.
     */
    get isConnected(): boolean;
    /**
     * Sets the connected state.
     *
     * @param isConnected "true" if connected.
     */
    set isConnected(isConnected: boolean);
    /**
     * Returns as.
     *
     * @return as.
     */
    get as(): string;
    /**
     * Sets crossOrigin.
     *
     * @param crossOrigin crossOrigin.
     */
    set as(as: string);
    /**
     * Returns crossOrigin.
     *
     * @return crossOrigin.
     */
    get crossOrigin(): string;
    /**
     * Sets crossOrigin.
     *
     * @param crossOrigin crossOrigin.
     */
    set crossOrigin(crossOrigin: string);
    /**
     * Returns href.
     *
     * @return Href.
     */
    get href(): string;
    /**
     * Sets href.
     *
     * @param href Href.
     */
    set href(href: string);
    /**
     * Returns hreflang.
     *
     * @return hreflang.
     */
    get hreflang(): string;
    /**
     * Sets hreflang.
     *
     * @param hreflang hreflang.
     */
    set hreflang(hreflang: string);
    /**
     * Returns media.
     *
     * @return media.
     */
    get media(): string;
    /**
     * Sets media.
     *
     * @param media media.
     */
    set media(media: string);
    /**
     * Returns referrerPolicy.
     *
     * @return referrerPolicy.
     */
    get referrerPolicy(): string;
    /**
     * Sets referrerPolicy.
     *
     * @param referrerPolicy referrerPolicy.
     */
    set referrerPolicy(referrerPolicy: string);
    /**
     * Returns rel.
     *
     * @return rel.
     */
    get rel(): string;
    /**
     * Sets rel.
     *
     * @param rel rel.
     */
    set rel(rel: string);
    /**
     * Returns type.
     *
     * @return type.
     */
    get type(): string;
    /**
     * Sets type.
     *
     * @param type type.
     */
    set type(type: string);
    /**
     * The setAttributeNode() method adds a new Attr node to the specified element.
     *
     * @override
     * @param attribute Attribute.
     * @returns Replaced attribute.
     */
    setAttributeNode(attribute: Attr): Attr;
}
